'pysourceinfo.PySourceInfo' - Module
**************************************

.. automodule:: pysourceinfo.PySourceInfo

Functions
---------

getCallerFileName
^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerFileName

getCallerFilePathName
^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerFilePathName

getCallerFuncName
^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerFuncName

getCallerLinenumber
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerLinenumber

getCallerModule
^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModule

getCallerModuleFilePathName
^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModuleFilePathName

getCallerModuleName
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModuleName 

getCallerModulePathName
^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModulePathName

getCallerModulePythonPath
^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModulePythonPath

getCallerName
^^^^^^^^^^^^^
	.. autofunction:: getCallerName

getCallerNameOID
^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerNameOID

getCallerNamespaceGlobal
^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerNamespaceGlobal

getCallerNamespaceLocal
^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerNamespaceLocal

getCallerPackageFilePathName
^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackageFilePathName

getCallerPackageName
^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackageName

getCallerPackagePathName
^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackagePathName

getCallerPackagePythonPath
^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackagePythonPath


getCallerSysPathPackageName
^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerSysPathPackageName

getCallerSysPathPackageSysPathName
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerSysPathPackageSysPathName

getCallerSysPathPackageSysPathNameRel
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerSysPathPackageSysPathNameRel

getCallerSysPathPackagePythonPath
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerSysPathPackagePythonPath

getCallerPathName
^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPathName


getModuleFilePathName
^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getModuleFilePathName

getModulePathName
^^^^^^^^^^^^^^^^^
	.. autofunction:: getModulePathName

getModuleSourceFilePathName
^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getModuleSourceFilePathName

getPythonPathFromSysPath
^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathFromSysPath

getPythonPathRel
^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathRel

getStackFuncList
^^^^^^^^^^^^^^^^
	.. autofunction:: getStackFuncList

getStackFuncMap
^^^^^^^^^^^^^^^
	.. autofunction:: getStackFuncMap

getStackFuncNameList
^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getStackFuncNameList

getStackFuncNameMap
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getStackFuncNameMap

getStackLen
^^^^^^^^^^^
	.. autofunction:: getStackLen

getStackSposForFunc
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getStackSposForFunc

getStackSposForFuncName
^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getStackSposForFuncName

